pm4py.algo.conformance.alignments.edit\_distance.variants package
=================================================================

Submodules
----------

pm4py.algo.conformance.alignments.edit\_distance.variants.edit\_distance module
-------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.edit_distance.variants.edit_distance
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments.edit_distance.variants
   :members:
   :undoc-members:
   :show-inheritance:
